@@ -96,6 +96,8 @@ class Update(JsonDeserializable):
         update_id = obj['update_id']
         message = None
         edited_message = None
+        channel_post = None
+        edited_channel_post = None
         inline_query = None
         chosen_inline_result = None
         callback_query = None
@@ -103,19 +105,27 @@ class Update(JsonDeserializable):
             message = Message.de_json(obj['message'])
         if 'edited_message' in obj:
             edited_message = Message.de_json(obj['edited_message'])
+        if 'channel_post' in obj:
+            channel_post = Message.de_json(obj['channel_post'])
+        if 'edited_channel_post' in obj:
+            edited_channel_post = Message.de_json(obj['edited_channel_post'])
         if 'inline_query' in obj:
             inline_query = InlineQuery.de_json(obj['inline_query'])
         if 'chosen_inline_result' in obj:
             chosen_inline_result = ChosenInlineResult.de_json(obj['chosen_inline_result'])
         if 'callback_query' in obj:
             callback_query = CallbackQuery.de_json(obj['callback_query'])
-        return cls(update_id, message, edited_message, inline_query, chosen_inline_result, callback_query)
+        return cls(update_id, message, edited_message, channel_post, edited_channel_post, inline_query,
+                   chosen_inline_result, callback_query)
 
-    def __init__(self, update_id, message, edited_message, inline_query, chosen_inline_result, callback_query):
+    def __init__(self, update_id, message, edited_message, channel_post, edited_channel_post, inline_query,
+                 chosen_inline_result, callback_query):
         self.update_id = update_id
         self.edited_message = edited_message
         self.message = message
         self.edited_message = edited_message
+        self.channel_post = channel_post
+        self.edited_channel_post = edited_channel_post
         self.inline_query = inline_query
         self.chosen_inline_result = chosen_inline_result
         self.callback_query = callback_query
@@ -187,7 +197,8 @@ class Chat(JsonDeserializable):
         all_members_are_administrators = obj.get('all_members_are_administrators')
         return cls(id, type, title, username, first_name, last_name, all_members_are_administrators)
 
-    def __init__(self, id, type, title=None, username=None, first_name=None, last_name=None, all_members_are_administrators=None):
+    def __init__(self, id, type, title=None, username=None, first_name=None, last_name=None,
+                 all_members_are_administrators=None):
         self.type = type
         self.last_name = last_name
         self.first_name = first_name
@@ -213,8 +224,10 @@ class Message(JsonDeserializable):
             opts['forward_from'] = User.de_json(obj['forward_from'])
         if 'forward_from_chat' in obj:
             opts['forward_from_chat'] = Chat.de_json(obj['forward_from_chat'])
+        if 'forward_from_message_id' in obj:
+            opts['forward_from_message_id'] = obj.get('forward_from_message_id')
         if 'forward_date' in obj:
-            opts['forward_date'] = obj['forward_date']
+            opts['forward_date'] = obj.get('forward_date')
         if 'reply_to_message' in obj:
             opts['reply_to_message'] = Message.de_json(obj['reply_to_message'])
         if 'edit_date' in obj:
@@ -572,12 +585,12 @@ class ForceReply(JsonSerializable):
         return json.dumps(json_dict)
 
 
-class ReplyKeyboardHide(JsonSerializable):
+class ReplyKeyboardRemove(JsonSerializable):
     def __init__(self, selective=None):
         self.selective = selective
 
     def to_json(self):
-        json_dict = {'hide_keyboard': True}
+        json_dict = {'remove_keyboard': True}
         if self.selective:
             json_dict['selective'] = True
         return json.dumps(json_dict)
